@@ -430,10 +430,10 @@ void buffer_write_to_file(int fd_o,
 	struct timespec *buf;
 	struct timespec base, diff;
 	lkst_tsc_t base_cnt, log_cnt, diff_cnt;
-	static int write_once_flag = 0;
+	static int write_first_time = 1;
 
 	/* write log header and info-record */
-	if(!write_once_flag){
+	if(write_first_time){
 		log_header_t logh = {
 			log_magic: LOGFILE_MAGIC,
 			log_version: 0
@@ -442,12 +442,12 @@ void buffer_write_to_file(int fd_o,
 			log_size: 2*sizeof(int) + sizeof(char)*LKST_ARCH_NAME_LEN,
 			log_format:PXLOG_BINARY
 		};
-		write_once_flag=1;
 		write(fd_o, &logh, sizeof(log_header_t));
 		write(fd_o, &posix_entry, sizeof(struct posix_log_entry));
 		write(fd_o, &(lbuffer->endian_big), sizeof(int));
 		write(fd_o, &(lbuffer->buf_ver), sizeof(int));
 		write(fd_o, lbuffer->arch, sizeof(char)*LKST_ARCH_NAME_LEN);
+		write_first_time=0;
 	}
 
 	/* convert mc to time */
